@@ -1,6 +1,4 @@
-#![feature(allocator_api)]
-#![feature(destructuring_assignment)]
-#![doc(html_root_url = "https://docs.rs/kiddo/0.1.5")]
+#![doc(html_root_url = "https://docs.rs/kiddo/0.1.6")]
 #![doc(issue_tracker_base_url = "https://github.com/sdd/kiddo/issues/")]
 
 //! # kiddo
@@ -16,7 +14,7 @@
 //! Add `kiddo` to `Cargo.toml`
 //! ```toml
 //! [dependencies]
-//! kiddo = "0.1.5"
+//! kiddo = "0.1.6"
 //! ```
 //!
 //! ## Usage
